@@ -214,11 +214,11 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
 
         asyncore.loop(map=self._map)
 
-    def make_rsp(self, **kwargs):
+    def make_rsp(self, *args, **kwargs):
         """
         生成rsp
         """
-        return json.dumps(kwargs) + self.terminator
+        return json.dumps(dict(*args, **kwargs)) + self.terminator
 
 
 class TcpRequestHandler(asynchat.async_chat):
@@ -314,11 +314,11 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
 
         asyncore.loop(map=self._map)
 
-    def make_rsp(self, **kwargs):
+    def make_rsp(self, *args, **kwargs):
         """
         生成rsp
         """
-        return json.dumps(kwargs)
+        return json.dumps(dict(*args, **kwargs))
 
 
 class UdpRequestHandler(object):
